==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/vmwarecloudsimple/kotlin/inputs/GuestOSCustomizationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.vmwarecloudsimple.kotlin.inputs

import com.pulumi.azurenative.vmwarecloudsimple.inputs.GuestOSCustomizationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Guest OS Customization properties
 * @property dnsServers List of dns servers to use
 * @property hostName Virtual Machine hostname
 * @property password Password for login
 * @property policyId id of customization policy
 * @property username Username for login
 */
public data class GuestOSCustomizationArgs(
    public val dnsServers: Output<List<String>>? = null,
    public val hostName: Output<String>? = null,
    public val password: Output<String>? = null,
    public val policyId: Output<String>? = null,
    public val username: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.vmwarecloudsimple.inputs.GuestOSCustomizationArgs> {
    override fun toJava(): com.pulumi.azurenative.vmwarecloudsimple.inputs.GuestOSCustomizationArgs =
        com.pulumi.azurenative.vmwarecloudsimple.inputs.GuestOSCustomizationArgs.builder()
            .dnsServers(dnsServers?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .hostName(hostName?.applyValue({ args0 -> args0 }))
            .password(password?.applyValue({ args0 -> args0 }))
            .policyId(policyId?.applyValue({ args0 -> args0 }))
            .username(username?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [GuestOSCustomizationArgs].
 */
@PulumiTagMarker
public class GuestOSCustomizationArgsBuilder internal constructor() {
    private var dnsServers: Output<List<String>>? = null

    private var hostName: Output<String>? = null

    private var password: Output<String>? = null

    private var policyId: Output<String>? = null

    private var username: Output<String>? = null

    /**
     * @param value List of dns servers to use
     */
    @JvmName("whvlakeklqwxnvda")
    public suspend fun dnsServers(`value`: Output<List<String>>) {
        this.dnsServers = value
    }

    @JvmName("nafixcmqlxmnxvci")
    public suspend fun dnsServers(vararg values: Output<String>) {
        this.dnsServers = Output.all(values.asList())
    }

    /**
     * @param values List of dns servers to use
     */
    @JvmName("vvkoitfeufkxgpdd")
    public suspend fun dnsServers(values: List<Output<String>>) {
        this.dnsServers = Output.all(values)
    }

    /**
     * @param value Virtual Machine hostname
     */
    @JvmName("jeojdskkwanofpke")
    public suspend fun hostName(`value`: Output<String>) {
        this.hostName = value
    }

    /**
     * @param value Password for login
     */
    @JvmName("dwxsuslydflfqgst")
    public suspend fun password(`value`: Output<String>) {
        this.password = value
    }

    /**
     * @param value id of customization policy
     */
    @JvmName("qvgcveqhrimycnaj")
    public suspend fun policyId(`value`: Output<String>) {
        this.policyId = value
    }

    /**
     * @param value Username for login
     */
    @JvmName("lmfyvcvjoocguukl")
    public suspend fun username(`value`: Output<String>) {
        this.username = value
    }

    /**
     * @param value List of dns servers to use
     */
    @JvmName("tdaryblwjjemfynk")
    public suspend fun dnsServers(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dnsServers = mapped
    }

    /**
     * @param values List of dns servers to use
     */
    @JvmName("adghwqdamanwbyvc")
    public suspend fun dnsServers(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dnsServers = mapped
    }

    /**
     * @param value Virtual Machine hostname
     */
    @JvmName("qlarsvymndgvlcsu")
    public suspend fun hostName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.hostName = mapped
    }

    /**
     * @param value Password for login
     */
    @JvmName("gljeilefovdmqldc")
    public suspend fun password(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.password = mapped
    }

    /**
     * @param value id of customization policy
     */
    @JvmName("gaqelfokpiyoproc")
    public suspend fun policyId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.policyId = mapped
    }

    /**
     * @param value Username for login
     */
    @JvmName("ahluknvnodenllap")
    public suspend fun username(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.username = mapped
    }

    internal fun build(): GuestOSCustomizationArgs = GuestOSCustomizationArgs(
        dnsServers = dnsServers,
        hostName = hostName,
        password = password,
        policyId = policyId,
        username = username,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/vmwarecloudsimple/kotlin/inputs/GuestOSCustomizationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.vmwarecloudsimple.kotlin.inputs

import com.pulumi.azurenative.vmwarecloudsimple.inputs.GuestOSCustomizationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Guest OS Customization properties
 * @property dnsServers List of dns servers to use
 * @property hostName Virtual Machine hostname
 * @property password Password for login
 * @property policyId id of customization policy
 * @property username Username for login
 */
public data class GuestOSCustomizationArgs(
    public val dnsServers: Output<List<String>>? = null,
    public val hostName: Output<String>? = null,
    public val password: Output<String>? = null,
    public val policyId: Output<String>? = null,
    public val username: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.vmwarecloudsimple.inputs.GuestOSCustomizationArgs> {
    override fun toJava(): com.pulumi.azurenative.vmwarecloudsimple.inputs.GuestOSCustomizationArgs =
        com.pulumi.azurenative.vmwarecloudsimple.inputs.GuestOSCustomizationArgs.builder()
            .dnsServers(dnsServers?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .hostName(hostName?.applyValue({ args0 -> args0 }))
            .password(password?.applyValue({ args0 -> args0 }))
            .policyId(policyId?.applyValue({ args0 -> args0 }))
            .username(username?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [GuestOSCustomizationArgs].
 */
@PulumiTagMarker
public class GuestOSCustomizationArgsBuilder internal constructor() {
    private var dnsServers: Output<List<String>>? = null

    private var hostName: Output<String>? = null

    private var password: Output<String>? = null

    private var policyId: Output<String>? = null

    private var username: Output<String>? = null

    /**
     * @param value List of dns servers to use
     */
    @JvmName("allubyhtfawurouq")
    public suspend fun dnsServers(`value`: Output<List<String>>) {
        this.dnsServers = value
    }

    @JvmName("focfuqyovklrencu")
    public suspend fun dnsServers(vararg values: Output<String>) {
        this.dnsServers = Output.all(values.asList())
    }

    /**
     * @param values List of dns servers to use
     */
    @JvmName("pcbyoolioxjkrjju")
    public suspend fun dnsServers(values: List<Output<String>>) {
        this.dnsServers = Output.all(values)
    }

    /**
     * @param value Virtual Machine hostname
     */
    @JvmName("fsfbeoflvfljawxp")
    public suspend fun hostName(`value`: Output<String>) {
        this.hostName = value
    }

    /**
     * @param value Password for login
     */
    @JvmName("uyfqehwflbhlklcn")
    public suspend fun password(`value`: Output<String>) {
        this.password = value
    }

    /**
     * @param value id of customization policy
     */
    @JvmName("qnadkffpfdfnpmum")
    public suspend fun policyId(`value`: Output<String>) {
        this.policyId = value
    }

    /**
     * @param value Username for login
     */
    @JvmName("kaouddlkhfrdkbnw")
    public suspend fun username(`value`: Output<String>) {
        this.username = value
    }

    /**
     * @param value List of dns servers to use
     */
    @JvmName("fdawsrrsgdjefstl")
    public suspend fun dnsServers(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dnsServers = mapped
    }

    /**
     * @param values List of dns servers to use
     */
    @JvmName("beutjkywibdhllyn")
    public suspend fun dnsServers(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dnsServers = mapped
    }

    /**
     * @param value Virtual Machine hostname
     */
    @JvmName("gubpliwsrlxfyfjm")
    public suspend fun hostName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.hostName = mapped
    }

    /**
     * @param value Password for login
     */
    @JvmName("tcdskigfqercduai")
    public suspend fun password(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.password = mapped
    }

    /**
     * @param value id of customization policy
     */
    @JvmName("mtqihnuphecoosnm")
    public suspend fun policyId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.policyId = mapped
    }

    /**
     * @param value Username for login
     */
    @JvmName("qdubbyluarxhyqhk")
    public suspend fun username(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.username = mapped
    }

    internal fun build(): GuestOSCustomizationArgs = GuestOSCustomizationArgs(
        dnsServers = dnsServers,
        hostName = hostName,
        password = password,
        policyId = policyId,
        username = username,
    )
}
